@@ -1,8 +1,7 @@
 #!/usr/bin/env perl
-use 5.010000;
+use 5.008000;
 use warnings;
 use strict;
-use utf8;
 
 use Term::Choose qw( choose );
 
@@ -44,4 +43,4 @@ my $mixed_options_2 = Data_Test_Arguments::mixed_invalid_2();
 eval { choose( [], $mixed_options_1 ); 1 } and die 'choose( <<< );';
 
 
-say "<End_fc_ia>";
+print "<End_fc_ia>\n";
